<?php

namespace Drupal\pixelsize\Plugin\Field\FieldWidget;

use Drupal;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'PixelsizeDefaultWidget' widget.
 *
 * @FieldWidget(
 *   id = "PixelsizeDefaultWidget",
 *   label = @Translation("Pixel Size"),
 *   field_types = {
 *     "Pixelsize"
 *   }
 * )
 */
class PixelsizeDefaultWidget extends WidgetBase {

  /**
   * Define the form for the field type.
   *
   * Inside this method we can define the form used to edit the field type.
   *
   */
  public function formElement(
    FieldItemListInterface $items,
    $delta,
    Array $element,
    Array &$form,
    FormStateInterface $formState
  ) {
    $element['pixelset']= [
      '#type' => 'container',
      '#attributes' => ['class' => ['clearfix', 'pixelsize-set']],
      '#attached' => [
        'library' => 'pixelsize/widget',
        ],
    ];
    // Width
    $element['pixelset']['width'] = [
      '#type' => 'number',
      '#title' => t('Width'),
      '#min' => 1,
      '#step' => 1,
      '#size' => 3,
      '#field_suffix' => $this->t('px'),
      '#default_value' => isset($items[$delta]->width) ?  $items[$delta]->width : null,
      '#empty_value' => '',
    ];

    $element['pixelset']['by'] = [
      '#type' => 'item',
      '#markup' => $this->t('×'),
   ];

    // Height
    $element['pixelset']['height'] = [
      '#type' => 'number',
      '#title' => t('Height'),
      '#min' => 1,
      '#step' => 1,
      '#size' => 3,
      '#field_suffix' => $this->t('px'),
      '#default_value' => isset($items[$delta]->height) ?  $items[$delta]->height : null,
      '#empty_value' => '',
    ];

    return $element;
  }

}
